from src.tcolor.classes.Code import Code
from src.tcolor.classes.Text import Text
from src.tcolor.classes.Background import Background
from src.tcolor.classes.Format import Format
from src.tcolor.classes.Print import Print

